.. _policy-configuration:

====================
Policy configuration
====================

Configuration
~~~~~~~~~~~~~

The following is an overview of all available policies in Cinder.  For
information on how to write a custom policy file to modify these policies,
see :ref:`policy-file` in the Cinder configuration documentation.

.. show-policy::
   :config-file: tools/config/cinder-policy-generator.conf
